import express from "express";
import { Request, Response, NextFunction } from "express";
import http from "http";
import StreamManager from "./StreamManager";
import { StreamStartInfo } from "./types";

import config from "./config.json";

const app = express();
app.use(express.json());

const port = config.backend.port;
const streamManager: StreamManager = new StreamManager();

app.get("/transmit/list", (req, res) => {
  console.log(config.backend.loggingPrefix + "received get /transmit/list");
  res.status(200).send(streamManager.getStreamsDataForm());
});

//#region CRUD Single Transmission
app.post("/transmit/create", (req, res) => {
  console.log(config.backend.loggingPrefix + "received post /transmit/create");
  let ssi: StreamStartInfo = req.body;
  console.log(config.backend.loggingPrefix + "body :", ssi);
  res.status(200).send(streamManager.createTransmission(ssi));
});

app.post("/transmit/update/:id", (req, res) => {
  console.log(config.backend.loggingPrefix + "received post /transmit/update/");
  console.log(config.backend.loggingPrefix + "param id: " + req.params.id);
  let ssi: StreamStartInfo = req.body;
  console.log(config.backend.loggingPrefix + "body :", ssi);
  res.status(200).send(streamManager.updateTransmission(req.params.id, ssi));
});

app.get("/transmit/find/:id", (req, res) => {
  console.log(config.backend.loggingPrefix + "received get /transmit/find/");
  console.log(config.backend.loggingPrefix + "param id: " + req.params.id);
  res.status(200).send(streamManager.getStream(req.params.id));
});

app.get("/transmit/start/:id", (req, res) => {
  console.log(config.backend.loggingPrefix + "received get /transmit/start/");
  console.log(config.backend.loggingPrefix + "param id: " + req.params.id);
  res.status(200).send(streamManager.startStream(req.params.id));
});

app.get("/transmit/stop/:id", (req, res) => {
  console.log(config.backend.loggingPrefix + "received get /transmit/stop/");
  console.log(config.backend.loggingPrefix + "param id: " + req.params.id);
  res.status(200).send(streamManager.stopStream(req.params.id));
});

app.get("/transmit/delete/:id", (req, res) => {
  console.log(config.backend.loggingPrefix + "received get /transmit/delete/");
  console.log(config.backend.loggingPrefix + "param id: " + req.params.id);
  res.status(200).send(streamManager.deleteStream(req.params.id));
});

//#endregion
//module.exports = app;

//#region SSE
const setupEventStream = (req: Request, res: Response) => {
  res.setHeader("Content-Type", "text/event-stream");
  res.setHeader("Cache-Control", "no-cache");

  res.setHeader(
    "Access-Control-Allow-Origin",
    `${config.frontend.publicHostName}:${config.frontend.publicPort}`
  );
  res.setHeader("Access-Control-Allow-Credentials", "true");

  res.flushHeaders();

  return (res: Response, data: any) => {
    res.write(`data:${JSON.stringify(data)}\n\n`);
  };
};

app.get("/SLTUpdate", (req: Request, res: Response, next) => {
  console.log(config.backend.loggingPrefix + "received get /SLTUpdate");

  const sendEventStreamData = setupEventStream(req, res);

  function updateHandler(data: any) {
    sendEventStreamData(res, data);
  }

  streamManager.STLMUpdate.on("event", updateHandler);
  console.log(config.backend.loggingPrefix + "addedListener SLTUpdate");

  res.on("close", () => {
    streamManager.STLMUpdate.removeListener("event", updateHandler);
    console.log(config.backend.loggingPrefix + "removedListener SLTUpdate");
    res.end();
  });
});

//#endregion
app.listen(port, () => {
  console.log(config.backend.loggingPrefix + `Started on port: ${port}`);
});
