import { Stream, StreamStartInfo } from "./types";
import config from "./config.json";
import { defaultProfile } from "./components/StreamStartPanel";

// Taken from https://developer.mozilla.org/en-US/docs/Web/API/Fetch_API/Using_Fetch
// Example POST method implementation:
/*
async function postData(url: string = "", data: object = {}) {
  // Default options are marked with *
  const response = await fetch(url, {
    method: "POST", // *GET, POST, PUT, DELETE, etc.
    //mode: "no-cors", // no-cors, *cors, same-origin
    cache: "no-cache", // *default, no-cache, reload, force-cache, only-if-cached
    credentials: "same-origin", // include, *same-origin, omit
    headers: {
      Accept: "application/json",
      "Content-Type": "application/json",
      // 'Content-Type': 'application/x-www-form-urlencoded',
    },
    redirect: "follow", // manual, *follow, error
    referrerPolicy: "no-referrer", // no-referrer, *no-referrer-when-downgrade, origin, origin-when-cross-origin, same-origin, strict-origin, strict-origin-when-cross-origin, unsafe-url
    body: JSON.stringify(data), // body data type must match "Content-Type" header
  });
  return response.json(); // parses JSON response into native JavaScript objects
}
*/

async function postDataReturnString(
  url: string = "",
  data: object = {}
): Promise<string> {
  // Default options are marked with *
  const response = await fetch(url, {
    method: "POST", // *GET, POST, PUT, DELETE, etc.
    //mode: "no-cors", // no-cors, *cors, same-origin
    cache: "no-cache", // *default, no-cache, reload, force-cache, only-if-cached
    credentials: "same-origin", // include, *same-origin, omit
    headers: {
      "Content-Type": "application/json",
      // 'Content-Type': 'application/x-www-form-urlencoded',
      //"Content-Type": "text",
    },
    redirect: "follow", // manual, *follow, error
    referrerPolicy: "no-referrer", // no-referrer, *no-referrer-when-downgrade, origin, origin-when-cross-origin, same-origin, strict-origin, strict-origin-when-cross-origin, unsafe-url
    body: JSON.stringify(data), // body data type must match "Content-Type" header
  });
  return response.text();
}

/*Example usage:
  postData("https://example.com/answer", { answer: 42 }).then((data) => {
    console.log(data); // JSON data parsed by `data.json()` call
  });
*/

const url = `${config.backend.url}:${config.frontend.port}`;

export async function createStream(data: StreamStartInfo): Promise<string> {
  const routeUrl = url + config.backend.routes.createStream;
  return postDataReturnString(routeUrl, data);
}

export async function updateStream(data: Stream): Promise<string> {
  let startInfo: StreamStartInfo = {
    name: data.name,
    listenerParams: data.listenerParams,
    callerParams: data.callerParams,
    status: null,
    ndiProfile: defaultProfile,
  };
  const routeUrl = url + config.backend.routes.updateStream + data.id;
  return postDataReturnString(routeUrl, startInfo);
}

export async function findStream(id: string): Promise<Stream> {
  const routeUrl = url + config.backend.routes.findStream + id;
  return (await fetch(routeUrl)).json();
}

export async function startStream(id: string): Promise<string> {
  const routeUrl = url + config.backend.routes.startStream + id;
  return (await fetch(routeUrl)).text();
}

export async function stopStream(id: string): Promise<string> {
  const routeUrl = url + config.backend.routes.stopStream + id;
  return (await fetch(routeUrl)).text();
}
export async function deleteStream(id: string): Promise<string> {
  const routeUrl = url + config.backend.routes.deleteStream + id;
  return (await fetch(routeUrl)).text();
}
export async function getStreams(): Promise<Stream[]> {
  const routeUrl = url + config.backend.routes.getStreams;
  return (await fetch(routeUrl)).json();
}
