import React, { useEffect, useState } from "react";
import StreamMonitor from "./StreamMonitor";
import { Stream } from "./../types";
import { getStreams } from "../backend-utils";
import StreamStartPanel from "./StreamStartPanel";
import config from "./../config.json";
import { Box } from "@material-ui/core";

const useEventSource: (url: string) => [Stream[], (streams: Stream[]) => any] =
  (url) => {
    const [streams, setStreams] = useState<Stream[]>([]);

    useEffect(() => {
      const source = new EventSource(url, { withCredentials: true });
      source.onmessage = function logEvents(event) {
        console.log(`Got event`, JSON.parse(event.data));
        setStreams(JSON.parse(event.data));
      };

      //Moved From source.onopen for iOS support

      getStreams().then((streams) => setStreams(streams));
      /* source.onopen = function getInitial() {
        getStreams().then((streams) => setStreams(streams));
      }; */

      source.onerror = function logError(ev: Event) {
        console.log("Lost connection to SLTUpdate?:", ev);
      };

      return () => {
        source.close();
      };
    }, [url]);

    return [streams || [], setStreams];
  };

export default function ControlPanel() {
  //const streams = useEventSource(
  //TODO: Figure out why we need backend port here
  //`${config.backend.url}:${config.backend.port}/SLTUpdate`

  const [streams, setStreams] = useEventSource(
    `${config.backend.url}:${config.backend.port}/SLTUpdate/`
  );
  return (
    <Box component="div" className="Control-Panel">
      <StreamStartPanel />
      <StreamMonitor streams={streams} setStreams={setStreams} />
    </Box>
  );
}
