import { IconButton as Box, Tooltip } from "@material-ui/core";
import QRCodes from "qrcode";
import React, { useEffect, useState } from "react";

export type QRCodeProps = { text: string };

export default function QRCode({ text }: QRCodeProps) {
  const [svg, setSvg] = useState<string>("");
  const [size, setSize] = useState<number>(50);

  useEffect(() => {
    console.log("creating QR with url: ", text);
    QRCodes.toString(text, { type: "svg" }).then((str) => {
      setSvg(str);
      console.log("LOADED");
    });
  }, [text]);

  const onQRCodeClick = () => {
    if (size < 51) {
      setSize(459);
    } else {
      setSize(50);
    }
  };

  return (
    <Tooltip title={size < 51 ? "Grow" : "Shrink"}>
      <Box>
        <div className="QR-Code">
          <img
            width={size}
            height={size}
            src={`data:image/svg+xml;utf8,${encodeURIComponent(svg)}`}
            onClick={onQRCodeClick}
            alt="QR-Code"
          />
        </div>
      </Box>
    </Tooltip>
  );
}
