import { IconButton, TextField, Tooltip } from "@material-ui/core";
import PublishIcon from "@material-ui/icons/Publish";
import { StreamStartInfo, NDIProfile } from "./../types";
import React, { ChangeEvent, useState } from "react";
import { createStream } from "../backend-utils";
import { StreamStatus } from "../enums";
import Select from "@material-ui/core/Select";
import MenuItem from "@material-ui/core/MenuItem";
import {
  defaultCallerParams,
  defaultListenerParams,
  ndiProfiles,
} from "../utils/profiles";
import config from "../config.json";

export const defaultProfile: NDIProfile = ndiProfiles[config.UI.DefaultProfile];

export default function StreamStartPanel() {
  const [stream, setStream] = useState<StreamStartInfo>({
    name: "",
    listenerParams: defaultListenerParams,
    callerParams: defaultCallerParams,
    status: config.UI.StreamsStartOnCreate
      ? StreamStatus.STARTED
      : StreamStatus.STOPPED,
    ndiProfile: defaultProfile,
  });
  const [message, setMessage] = useState<string>("");

  const onTextFieldChange = (
    event: ChangeEvent<HTMLInputElement | HTMLTextAreaElement>
  ) => {
    setStream({
      name: event.target.value,
      listenerParams: stream.listenerParams,
      callerParams: stream.callerParams,
      status: stream.status,
      ndiProfile: stream.ndiProfile,
    });
  };

  const onPublish = () => {
    createStream(stream).then(setMessage);
    setStream({
      name: "",
      listenerParams: defaultListenerParams,
      callerParams: defaultCallerParams,
      status: StreamStatus.STARTED,
      ndiProfile: defaultProfile,
    });
  };

  const onNameKeyDown = (event: React.KeyboardEvent) => {
    if (event.key === "Enter") {
      onPublish();
    }
  };

  const handleProfileChange = (event: React.ChangeEvent<{ value: unknown }>) =>
    setStream({
      name: "",
      listenerParams: defaultListenerParams,
      callerParams: defaultCallerParams,
      status: StreamStatus.STARTED,
      ndiProfile:
        ndiProfiles.find((p) => p.name === (event.target.value as string)) ||
        ndiProfiles[0],
    });

  return (
    <div className="Stream-Start-Panel">
      <Tooltip
        title="Create Stream"
        onContextMenu={(e: any) => e.preventDefault()}
      >
        <IconButton aria-label="create" onClick={onPublish}>
          <PublishIcon fontSize="large" htmlColor="#25DD25" />
        </IconButton>
      </Tooltip>

      <TextField
        color="secondary"
        id="name"
        label="Transmission Name"
        onChange={onTextFieldChange}
        value={stream.name}
        variant="filled"
        helperText={message}
        onKeyDown={onNameKeyDown}
      />

      <Select
        className="Profile-Select"
        value={stream.ndiProfile.name}
        onChange={handleProfileChange}
      >
        {ndiProfiles.map((profile) => (
          <MenuItem value={profile.name}>{profile.description}</MenuItem>
        ))}
      </Select>
    </div>
  );
}
