import { Stream } from "./types";

/**
 * based on https://softvelum.com/larix/grove/
 * @param stream
 * @returns encoded URI
 */
export function getGroveURL(stream: Stream): string {
  const streamURL = stream.connection.split("?")[0];

  const resolution = stream.ndiProfile.resolution;
  const height = resolution.height;
  const width = resolution.width;
  const fps = resolution.fps;

  let groveURL: string = `larix://set/v1?conn[][url]=${streamURL}&conn[][name]=${stream.name}`;
  let params = stream.listenerParams.filter(([key]) => key !== "mode");

  params.forEach(([key, value]) => {
    groveURL += `&conn[][srt${key}]=${value}`;
  });

  groveURL += `&conn[][overwrite]=on`; //overwrite not working properly?

  groveURL += `&enc[vid][res]=${width}x${height}&enc[vid][fps]=${fps}&enc[aud][samples]=${stream.ndiProfile.audiofreq}&enc[aud][channels]=1&enc[aud][bitrate]=320`;
  console.log(stream.name + " Grove URL:", groveURL);

  return encodeURI(groveURL);
}
