import { NDIProfile, Param } from "../types";

export const defaultCallerParams: Param[] = [
  ["mode", "caller"],
  ["latency", "2000"],
  /*  ["maxbw", "200000"], */
];

export const defaultListenerParams: Param[] = [
  ["mode", "listener"],
  ["latency", "2000"],
  ["maxbw", "0"],
  ["rcvbuf", "15000000"],
];

const sevenTwenty = (fps: number) => {
  return { width: 1280, height: 720, fps };
};

const tenEighty = (fps: number) => {
  return { width: 1920, height: 1080, fps };
};

export const ndiProfiles: NDIProfile[] = [
  {
    name: "ndi_720p60",
    description: "720P 60FPS",
    resolution: sevenTwenty(60),
    audiofreq: 48000,
  },
  {
    name: "ndi_720p50",
    description: "720P 50FPS",
    resolution: sevenTwenty(50),
    audiofreq: 48000,
  },
  {
    name: "ndi_1080p60",
    description: "1080P 60FPS",
    resolution: tenEighty(60),
    audiofreq: 48000,
  },
  {
    name: "ndi_1080p50",
    description: "1080P 50FPS",
    resolution: tenEighty(50),
    audiofreq: 48000,
  },
  {
    name: "ndi_1080p30",
    description: "1080P 30FPS",
    resolution: tenEighty(30),
    audiofreq: 48000,
  },
  {
    name: "ndi_1080p25",
    description: "1080P 25FPS",
    resolution: tenEighty(25),
    audiofreq: 48000,
  },
  {
    name: "transmit_ndi_1080p30",
    description: "T_1080P 30FPS",
    resolution: tenEighty(30),
    audiofreq: 22050,
  },
];

/*
transmit_ndi_1080p30 requires custom coder profile, see xml below:

<?xml version='1.0' encoding='utf-8'?>
<profile xmlns='http://www.vizrt.com/2013/vcos' id='transmit_ndi_1080p30'>
    <video>
        <aspect>16:9</aspect>
        <codec name='h264'>
            <rc_mode>vbr</rc_mode>
            <vendor codec='libx264' name='ffmpeg'/>
        </codec>
        <field_order>progressive</field_order>
        <fps>30:1</fps>
        <height>1080</height>
        <pixel_format>r8g8b8a8</pixel_format>
        <resize_mode>pad</resize_mode>
        <width>1920</width>
    </video>
    <audio>
        <channels>2</channels>
        <frequency>22050</frequency>
    </audio>
</profile>


*/
